@@ -5,9 +5,7 @@ readAffine <- function (fileName, type = NULL)
     
     lines <- readLines(fileName)
     typeLine <- (lines %~% "\\# affineType\\: \\w+")
-    if (!any(typeLine) && is.null(type))
-        report(OL$Error, "Type is not stored in the file - it must be specified")
-    else if (is.null(type))
+    if (is.null(type) && any(typeLine))
         type <- match.arg(tolower(sub("\\# affineType\\: (\\w+)", "\\1", lines[typeLine][1], perl=TRUE)), c("niftyreg","fsl"))
     
     connection <- textConnection(lines[!typeLine])
@@ -31,12 +29,10 @@ writeAffine <- function (affine, fileName)
     writeLines(lines, fileName)
 }
 
-convertAffine <- function (affine, source, target, newType = c("niftyreg","fsl"), currentType = NULL)
+convertAffine <- function (affine, source = NULL, target = NULL, newType = c("niftyreg","fsl"), currentType = NULL)
 {
     if (!is.matrix(affine) || !isTRUE(all.equal(dim(affine), c(4,4))))
         report(OL$Error, "Specified affine matrix is not valid")
-    if (!is.nifti(source) || !is.nifti(target))
-        report(OL$Error, "Source and target images must be specified as \"nifti\" objects")
     
     newType <- match.arg(newType)
     
@@ -68,19 +64,16 @@ convertAffine <- function (affine, source, target, newType = c("niftyreg","fsl")
     }
 }
 
+invertAffine <- function (affine)
+{
+    newAffine <- solve(affine)
+    attr(newAffine, "affineType") <- attr(affine, "affineType")
+    return (newAffine)
+}
+
 decomposeAffine <- function (affine, source = NULL, target = NULL, type = NULL)
 {
-    if (!is.matrix(affine) || !isTRUE(all.equal(dim(affine), c(4,4))))
-        report(OL$Error, "Specified affine matrix is not valid")
-    if (is.null(type))
-    {
-        type <- attr(affine, "affineType")
-        if (is.null(type))
-            report(OL$Error, "The current affine type was not specified and is not stored with the matrix")
-    }
-    
-    if (type == "niftyreg")
-        affine <- convertAffine(affine, source, target, "fsl", "niftyreg")
+    affine <- convertAffine(affine, source, target, "fsl", type)
     
     # Full matrix is rotationX %*% rotationY %*% rotationZ %*% skew %*% scale
     submatrix <- affine[1:3,1:3]
